#include <jde.h>

#define b551006_c



/*****************************************************************************
 *    Source File:  b551006
 *
 *    Description:  IBM Event Update function Source File
 *
 *        History:
 *          Date        Programmer  SAR# - Description
 *          ----------  ----------  -------------------------------------------
 *   Author 10/10/2003  Unknown     Unknown  - Created  
 *
 * Copyright (c) J.D. Edwards World Source Company, 1996
 *
 * This unpublished material is proprietary to J.D. Edwards World Source Company.
 * All rights reserved.  The methods and techniques described herein are
 * considered trade secrets and/or confidential.  Reproduction or
 * distribution, in whole or in part, is forbidden except by express
 * written permission of J.D. Edwards World Source Company.
 ****************************************************************************/
/**************************************************************************
 * Notes:
 *
 **************************************************************************/

#include <b551006.h>
#include <F5501005.h>
#include <stdio.h>
#include <stdlib.h>
#include <io.h>


/**************************************************************************
 *  Business Function:  Update_WBIAEvent
 *
 *        Description:  IBM Event Update Function
 *
 *         Parameters:
 *           LPBHVRCOM           lpBhvrCom    Business Function Communications
 *           LPVOID              lpVoid       Void Parameter - DO NOT USE!
 *           LPDSD5501005        lpDS         Parameter Data Structure Pointer  
 *
 *************************************************************************/

JDEBFRTN (ID) JDEBFWINAPI Update_WBIAEvent (LPBHVRCOM lpBhvrCom, LPVOID lpVoid, LPDSD5501005 lpDS)  
{
   /************************************************************************
    *  Variable declarations
    ************************************************************************/
	HENV			hEnv	=	NULL;
	HUSER			hUser	=	NULL;
	JDEDB_RESULT		rcode;
	HREQUEST		hRequest = NULL;

	ID                          idJDBReturn; 

	LPSELECT	lpSelect;
	
	int eventId = 0;
	

	F5501005 dsF5501005;
	FILE *myFile;

	DBREF		zDbRef = { 0 };
	NID pID[1] = {NID_EVT_STATUS};
	int updatedEvtStatus = 0;
	int count = 0;
	

   /************************************************************************
    * Declare structures
    ************************************************************************/

   /************************************************************************
    * Declare pointers
    ************************************************************************/

   /************************************************************************
    * Check for NULL pointers
    ************************************************************************/
   if ((lpBhvrCom == (LPBHVRCOM) NULL) ||
       (lpVoid    == (LPVOID)    NULL) ||
       (lpDS      == (LPDSD5501005)	NULL))
   {
     jdeErrorSet (lpBhvrCom, lpVoid, (ID) 0, "4363", (LPVOID) NULL);
     return ER_ERROR;
   }
	lpSelect =(LPSELECT) jdeAllocReturnIfError(COMMON_POOL, 1 * sizeof(SELECTSTRUCT), MEM_ZEROINIT);
	
	if(lpSelect == NULL)
	{
		printf ("Failed to allocate memory for selection criteria\n");
		return (1);
	}
   
	myFile = fopen("IBMEventsBFExecution.log","a+t");

	if(myFile == NULL){
	return(1);
	}


   /************************************************************************
    * Set pointers
    ************************************************************************/

   /************************************************************************
    * Main Processing
    ************************************************************************/
	
	

	idJDBReturn = JDB_InitBhvr(lpBhvrCom, &hUser, (char *)NULL, JDEDB_COMMIT_AUTO);
    	if (idJDBReturn == JDEDB_FAILED)
    	{
        	jdeSetGBRError (lpBhvrCom,lpVoid,(ID) 0,"078S");
		fclose(myFile);
        	return ER_ERROR;
    	}
	

	if ((rcode = JDB_InitEnv(&hEnv)) != JDEDB_PASSED)
	{
				
		fprintf(myFile, "JDB_InitEnv failed (returned %d).\n", rcode);
		
		fclose(myFile);
		return ER_ERROR;
	}

	if ((rcode = JDB_InitUser(hEnv, &hUser, NULL, JDEDB_COMMIT_AUTO)) != JDEDB_PASSED)
	{
		
		fprintf(myFile, "JDB_InitUser failed (returned %d)\n", rcode);
		
		fclose(myFile);
		return ER_ERROR;
	}	

	if (JDB_OpenTable (hUser, NID_F5501005, 0, NULL, (ushort)0, NULL, &hRequest) != JDEDB_PASSED)
	{
		
		fprintf (myFile, "Failed to open database table '%s'\n", NID_F5501005);
		
		fclose(myFile);
		return ER_ERROR;
	}
	
	
	eventId = lpDS->nEVENT_ID;

	
	fprintf(myFile, "EventId is:  %d\n", eventId);

	strcpy (lpSelect[0].Item1.szTable, NID_F5501005);
	lpSelect[0].Item1.idInstance	=	0;
	strcpy (lpSelect[0].Item2.szDict, "");
	strcpy (lpSelect[0].Item2.szTable, "");
	lpSelect[0].Item2.idInstance	=	0;
	lpSelect[0].nValues				=	1;
	lpSelect[0].nCmp				=	JDEDB_CMP_EQ;
	strcpy (lpSelect[0].Item1.szDict, NID_EVENT_ID);
	lpSelect[0].lpValue				=	&eventId;	
	
	
	// Set the selection information to empty
	if (JDB_ClearSelection (hRequest) != JDEDB_PASSED)
	{
		
		fprintf(myFile,"Failed to clear database selection.\n");

		fclose(myFile);
		jdeFree (lpSelect);
		return ER_ERROR;
	}else
	{
		
		fprintf(myFile,"Success to clear database selection.\n");
	}

	// Create WHERE clause
	if (JDB_SetSelection(hRequest, lpSelect, 1, JDEDB_SET_REPLACE) != JDEDB_PASSED)
	{
		
		fprintf (myFile, "Failed to set selection criteria\n");

		jdeFree (lpSelect);
		fclose(myFile);
		return ER_ERROR;
	}else
	{
		
		fprintf(myFile,"Success to set selection criteria\n");
	}

	// Select the records
	
	if (JDB_SelectKeyedForUpdate (hRequest,(ID) 0, (void *) NULL, (ushort) 0, pID, 1) != JDEDB_PASSED)
	{
		
		fprintf (myFile, "Select keyed failed.\n");

		jdeFree (lpSelect);
		fclose(myFile);
		return ER_ERROR;
	}	
	

	while(JDB_FetchForUpdate(hRequest, (LPVOID)&dsF5501005, 0))
	{
		
		{
		fprintf(myFile,"value of eventid is : <%d>\n", dsF5501005.xwevent_id);
		fprintf(myFile,"value of object name is : <%s>\n", dsF5501005.xwobj_name);
		fprintf(myFile,"value of object verb is : <%s>\n", dsF5501005.xwobj_verb);
		fprintf(myFile,"value of object key is : <%s>\n", dsF5501005.xwobj_key);
		fprintf(myFile,"value of event status before updation is : <%d>\n", dsF5501005.xwevt_status);
		}

		
		zDbRef.idInstance =0;
		jdeNIDcpy (zDbRef.szTable , NID_F5501005);
		jdeNIDcpy (zDbRef.szDict , NID_EVT_STATUS);

		
		updatedEvtStatus = lpDS->nEVENT_STATUS;

		
		fprintf(myFile,"udpated status is : <%d>\n", updatedEvtStatus);		
		
		if (JDB_AssignColumnValue (hRequest, zDbRef, EVDT_INT , &updatedEvtStatus) != JDEDB_PASSED )
		{
			
			fprintf (myFile, "Assign column value failed.\n");

			jdeFree (lpSelect);
			return ER_ERROR;
		}else
		{
				
				fprintf (myFile, "Assign cols succeeded.\n");
				JDB_CommitUser(hUser);
		}
		if (JDB_UpdateCurrent (hRequest, NID_F5501005, 0L, 0L, NULL, 0, NULL) != JDEDB_PASSED)
		{
			
			fprintf (myFile, "Update current failed.\n");

			jdeFree (lpSelect);
			return ER_ERROR;
		}else{
			
			fprintf (myFile, "Update current succeeded.\n");
			count = count + 1;
		}		
		

	}
	
			
			fprintf (myFile, "-----------End of Update_WBIAEvent-----------------\n");

   /************************************************************************
    * Function Clean Up
    ************************************************************************/
		fclose(myFile);
		// Cleanup the databsae connection
		JDB_CloseTable (hRequest);

		JDB_FreeBhvr(hUser);
		JDB_FreeUser (hUser);
		JDB_FreeEnv (hEnv);

   return (0);
}

/* Internal function comment block */
/**************************************************************************
 *   Function:  Ixxxxxxx_a   // Replace "xxxxxxx" with source file number
 *                           // and "a" with the function name
 *      Notes:
 *
 *    Returns:
 *
 * Parameters:
 **************************************************************************/

