#include <jde.h>
#include <b0000127.h>  
#define b551007_c



/*****************************************************************************
 *    Source File:  b551007
 *
 *    Description:  IBM Archive Business Function Source File
 *
 *        History:
 *          Date        Programmer  SAR# - Description
 *          ----------  ----------  -------------------------------------------
 *   Author 10/13/2003  Unknown     Unknown  - Created  
 *
 * Copyright (c) J.D. Edwards World Source Company, 1996
 *
 * This unpublished material is proprietary to J.D. Edwards World Source Company.
 * All rights reserved.  The methods and techniques described herein are
 * considered trade secrets and/or confidential.  Reproduction or
 * distribution, in whole or in part, is forbidden except by express
 * written permission of J.D. Edwards World Source Company.
 ****************************************************************************/
/**************************************************************************
 * Notes:
 *
 **************************************************************************/

#include <b551007.h>
#include <F5501005.h>
#include <F5501006.h>
#include <stdio.h>
#include <stdlib.h>
#include <io.h>


/**************************************************************************
 *  Business Function:  Archive_WBIAEvent
 *
 *        Description:  Archiving WBIA Event
 *
 *         Parameters:
 *           LPBHVRCOM           lpBhvrCom    Business Function Communications
 *           LPVOID              lpVoid       Void Parameter - DO NOT USE!
 *           LPDSD5501005        lpDS         Parameter Data Structure Pointer  
 *
 *************************************************************************/

JDEBFRTN (ID) JDEBFWINAPI Archive_WBIAEvent (LPBHVRCOM lpBhvrCom, LPVOID lpVoid, LPDSD5501005 lpDS)  
{
   /************************************************************************
    *  Variable declarations
    ************************************************************************/
	HENV			hEnv	=	NULL;
	HUSER			hUser	=	NULL;
	JDEDB_RESULT		rcode;
	HREQUEST		hRequest = NULL;

	ID                          idJDBReturn; 

	LPSELECT	lpSelect;
	
	int eventId = 0;
	DSD0000127 zDS11 = { 0 };

	F5501005 dsF5501005;
	F5501006 dsF5501006;
	FILE *myFile;

	char* obj_name, obj_verb, obj_key, evt_desc;
	int status = 3;
	char* description ="description not found";

	//DBREF		zDbRef = { 0 };
	//NID pID[1] = {NID_EVT_STATUS};
	//int updatedEvtStatus = 0;
	//int count = 0;

   /************************************************************************
    * Declare structures
    ************************************************************************/

   /************************************************************************
    * Declare pointers
    ************************************************************************/

   /************************************************************************
    * Check for NULL pointers
    ************************************************************************/
   if ((lpBhvrCom == (LPBHVRCOM) NULL) ||
       (lpVoid    == (LPVOID)    NULL) ||
       (lpDS      == (LPDSD5501005)	NULL))
   {
     jdeErrorSet (lpBhvrCom, lpVoid, (ID) 0, "4363", (LPVOID) NULL);
     return ER_ERROR;
   }
	lpSelect =(LPSELECT) jdeAllocReturnIfError(COMMON_POOL, 1 * sizeof(SELECTSTRUCT), MEM_ZEROINIT);
	
	if(lpSelect == NULL)
	{
		printf ("Failed to allocate memory for selection criteria\n");
		return (1);
	}
   
	myFile = fopen("IBMEventsBFExecution.log","a+t");

	if(myFile == NULL){
	return(1);
	}


   /************************************************************************
    * Set pointers
    ************************************************************************/

   /************************************************************************
    * Main Processing
    ************************************************************************/
	

	idJDBReturn = JDB_InitBhvr(lpBhvrCom, &hUser, (char *)NULL, JDEDB_COMMIT_AUTO);
    	if (idJDBReturn == JDEDB_FAILED)
    	{
        	jdeSetGBRError (lpBhvrCom,lpVoid,(ID) 0,"078S");
		fclose(myFile);
        	return ER_ERROR;
    	}	
	
	

	if ((rcode = JDB_InitEnv(&hEnv)) != JDEDB_PASSED)
	{
		printf("JDB_InitEnvOvr failed (returned %d).\n", rcode);
		fprintf(myFile,"JDB_InitEnvOvr failed (returned %d).", rcode); 
		fclose(myFile);
		return ER_ERROR;
	}

	if ((rcode = JDB_InitUser(hEnv, &hUser, NULL, JDEDB_COMMIT_AUTO)) != JDEDB_PASSED)
	{
		printf("JDB_InitUser failed (returned %d)\n", rcode);
		fprintf(myFile, "JDB_InitUser failed (returned %d)\n", rcode);
		fclose(myFile);
		return ER_ERROR;
	}	

	if (JDB_OpenTable (hUser, NID_F5501005, 0, NULL, (ushort)0, NULL, &hRequest) != JDEDB_PASSED)
	{
		printf ("Failed to open database table '%s'\n", NID_F5501005);
		fprintf(myFile,"Failed to open database table '%s'\n", NID_F5501005);
		fclose(myFile);
		return ER_ERROR;
	}
	
	
	eventId = lpDS->nEVENT_ID;
	fprintf(myFile, "EventId is:  %d\n", eventId);

	strcpy (lpSelect[0].Item1.szTable, NID_F5501005);
	lpSelect[0].Item1.idInstance	=	0;
	strcpy (lpSelect[0].Item2.szDict, "");
	strcpy (lpSelect[0].Item2.szTable, "");
	lpSelect[0].Item2.idInstance	=	0;
	lpSelect[0].nValues				=	1;
	lpSelect[0].nCmp				=	JDEDB_CMP_EQ;
	strcpy (lpSelect[0].Item1.szDict, NID_EVENT_ID);
	lpSelect[0].lpValue				=	&eventId;
	
	
	
	// Set the selection information to empty
	if (JDB_ClearSelection (hRequest) != JDEDB_PASSED)
	{
		
		fprintf(myFile,"Failed to clear database selection.\n");
		fclose(myFile);
		jdeFree (lpSelect);
		return ER_ERROR;
	}else
	{
		fprintf(myFile,"Success to clear database selection.\n");
	}

	// Create WHERE clause
	if (JDB_SetSelection(hRequest, lpSelect, 1, JDEDB_SET_REPLACE) != JDEDB_PASSED)
	{
		fprintf (myFile, "Failed to set selection criteria\n");
		jdeFree (lpSelect);
		fclose(myFile);
		return ER_ERROR;
	}else
	{
		fprintf(myFile,"Success to set selection criteria\n");
	}

	// Select the records
	
	if (JDB_SelectKeyed(hRequest,(ID) 0, (void *) NULL, (ushort) 0) != JDEDB_PASSED)
	{
		fprintf (myFile, "Select keyed failed.\n");
		jdeFree (lpSelect);
		fclose(myFile);
		return ER_ERROR;
	}		
	
	fprintf(myFile, "Select keyed succeeded.\n");

	while(JDB_Fetch(hRequest, (LPVOID)&dsF5501005, 0))
	{
		fprintf(myFile,"value of eventid is : <%d>\n", dsF5501005.xwevent_id);
		fprintf(myFile,"value of object name is : <%s>\n", dsF5501005.xwobj_name);
		fprintf(myFile,"value of object verb is : <%s>\n", dsF5501005.xwobj_verb);
		fprintf(myFile,"value of object key is : <%s>\n", dsF5501005.xwobj_key);
		fprintf(myFile,"value of event status before updation is : <%d>\n", dsF5501005.xwevt_status);

		dsF5501006.xwevent_id = dsF5501005.xwevent_id;
		dsF5501006.xwevt_status = dsF5501005.xwevt_status;
		dsF5501006.xwevt_prty = dsF5501005.xwevt_prty;
				
	
		strcpy(dsF5501006.xwobj_name, dsF5501005.xwobj_name);
		strcpy(dsF5501006.xwobj_verb, dsF5501005.xwobj_verb);
		strcpy(dsF5501006.xwobj_key, dsF5501005.xwobj_key);
		
		strcpy(dsF5501006.xwadapter_id, dsF5501005.xwadapter_id);
		
		dsF5501006.xwevt_time = dsF5501005.xwevt_time; 
		//dsF5501006.xwarchive_t=lpDS->jdARCHIVE_TIME;
        
		jdeCallObject( "ReturnTodaysDate" ,
     NULL , lpBhvrCom , (void *)lpVoid ,
      &zDS11 , (CALLMAP*)NULL , (int)0 ,
      (CHAR*)NULL , (CHAR*)NULL , (int)0 );
		JDEDATECopy( &dsF5501006.xwarchive_t , &zDS11.jdedateDateForToday );

		status = dsF5501006.xwevt_status;

		if(status == 2)
    		description = "Event is UnSubscribed";
    		else if(status == 3)
    		description = "Processing successful";
    		else if(status == -1)
    		description = "Error processing the event";
    		else if(status == -2)
    		description = "Error posting the event";
    		else if(status == -3)
    		description = "Error object not found";
    		else if(status == 0)
    		description = "Ready for polling";
    		else if(status == 1)
    		description = "In Progress";

		strcpy(dsF5501006.xwevt_desc, description);			

	}

	if (JDB_OpenTable (hUser, NID_F5501006, 0, NULL, (ushort)0, NULL, &hRequest) != JDEDB_PASSED)
	{
		printf ("Failed to open database table '%s'\n", NID_F5501006);
		fprintf(myFile,"Failed to open database table '%s'\n", NID_F5501006);
		fclose(myFile);
		return ER_ERROR;
	}

	if( JDB_InsertTable(hRequest, NID_F5501006, (ID)0, &dsF5501006) != JDEDB_PASSED)
	{

 		fprintf(myFile,"insert failed\n");
 		return ER_ERROR;

	} else{
 		fprintf(myFile,"insert succeeded\n");
	}



   /************************************************************************
    * Function Clean Up
    ************************************************************************/
		fclose(myFile);
		// Cleanup the databsae connection
		JDB_CloseTable (hRequest);

		JDB_FreeBhvr(hUser);
		JDB_FreeUser (hUser);
		JDB_FreeEnv (hEnv);

   return (0);
}

/* Internal function comment block */
/**************************************************************************
 *   Function:  Ixxxxxxx_a   // Replace "xxxxxxx" with source file number
 *                           // and "a" with the function name
 *      Notes:
 *
 *    Returns:
 *
 * Parameters:
 **************************************************************************/

