#include <jde.h>

#define b551008_c



/*****************************************************************************
 *    Source File:  b551008
 *
 *    Description:  IBM Event Delete Function Source File
 *
 *        History:
 *          Date        Programmer  SAR# - Description
 *          ----------  ----------  -------------------------------------------
 *   Author 10/13/2003  Unknown     Unknown  - Created  
 *
 * Copyright (c) J.D. Edwards World Source Company, 1996
 *
 * This unpublished material is proprietary to J.D. Edwards World Source Company.
 * All rights reserved.  The methods and techniques described herein are
 * considered trade secrets and/or confidential.  Reproduction or
 * distribution, in whole or in part, is forbidden except by express
 * written permission of J.D. Edwards World Source Company.
 ****************************************************************************/
/**************************************************************************
 * Notes:
 *
 **************************************************************************/

#include <b551008.h>
#include <F5501005.h>
#include <stdio.h>
#include <stdlib.h>
#include <io.h>


/**************************************************************************
 *  Business Function:  Delete_WBIAEvent
 *
 *        Description:  Deleting WBIA Event
 *
 *         Parameters:
 *           LPBHVRCOM           lpBhvrCom    Business Function Communications
 *           LPVOID              lpVoid       Void Parameter - DO NOT USE!
 *           LPDSD5501005        lpDS         Parameter Data Structure Pointer  
 *
 *************************************************************************/

JDEBFRTN (ID) JDEBFWINAPI Delete_WBIAEvent (LPBHVRCOM lpBhvrCom, LPVOID lpVoid, LPDSD5501005 lpDS)  
{
   /************************************************************************
    *  Variable declarations
    ************************************************************************/
	HENV			hEnv	=	NULL;
	HUSER			hUser	=	NULL;
	JDEDB_RESULT		rcode;
	HREQUEST		hRequest = NULL;

	ID                          idJDBReturn; 

	
	F5501005 dsF5501005;
	
	FILE *myFile;

	char* obj_name, obj_verb, obj_key, evt_desc;
   /************************************************************************
    * Declare structures
    ************************************************************************/

   /************************************************************************
    * Declare pointers
    ************************************************************************/

   /************************************************************************
    * Check for NULL pointers
    ************************************************************************/
   if ((lpBhvrCom == (LPBHVRCOM) NULL) ||
       (lpVoid    == (LPVOID)    NULL) ||
       (lpDS      == (LPDSD5501005)	NULL))
   {
     jdeErrorSet (lpBhvrCom, lpVoid, (ID) 0, _J("4363"), (LPVOID) NULL);
     return ER_ERROR;
   }
   
	myFile = fopen("IBMEventsBFExecution.log","a+t");

	if(myFile == NULL){
		return(1);
	}

   /************************************************************************
    * Set pointers
    ************************************************************************/

   /************************************************************************
    * Main Processing
    ************************************************************************/
	 

	idJDBReturn = JDB_InitBhvr(lpBhvrCom, &hUser, NULL, JDEDB_COMMIT_AUTO);
    	if (idJDBReturn == JDEDB_FAILED)
    	{
        	jdeSetGBRError (lpBhvrCom,lpVoid,(ID) 0,_J("078S"));
		fclose(myFile);
        	return ER_ERROR;
    	}	
		

	if ((rcode = JDB_InitEnv(&hEnv)) != JDEDB_PASSED)
	{
		
		fprintf(myFile,"JDB_InitEnvOvr failed (returned %d).", rcode); 
		fclose(myFile);
		return ER_ERROR;
	}

	if ((rcode = JDB_InitUser(hEnv, &hUser, NULL, JDEDB_COMMIT_AUTO)) != JDEDB_PASSED)
	{
		
		fprintf(myFile, "JDB_InitUser failed (returned %d)\n", rcode);
		fclose(myFile);
		return ER_ERROR;
	}	

	if (JDB_OpenTable (hUser, NID_F5501005, 0, NULL, (ushort)0, NULL, &hRequest) != JDEDB_PASSED)
	{
		
		fprintf(myFile,"Failed to open database table '%s'\n", NID_F5501005);
		fclose(myFile);
		return ER_ERROR;
	}	
	
	
	dsF5501005.xwevent_id = lpDS->nEVENT_ID;

	if( JDB_DeleteTable(hRequest, NID_F5501005, (ID)0, (ID)0 , &dsF5501005, 1) != JDEDB_PASSED)
	{

 		fprintf(myFile,"delete failed\n");
 		return(1);

	} else{
 		fprintf(myFile,"delete succeeded\n");
	}

	

   /************************************************************************
    * Function Clean Up
    ************************************************************************/

   		fclose(myFile);
		// Cleanup the database connection
		JDB_CloseTable (hRequest);

		JDB_FreeBhvr(hUser);
		JDB_FreeUser (hUser);
		JDB_FreeEnv (hEnv);

   return (0);
}

/* Internal function comment block */
/**************************************************************************
 *   Function:  Ixxxxxxx_a   // Replace "xxxxxxx" with source file number
 *                           // and "a" with the function name
 *      Notes:
 *
 *    Returns:
 *
 * Parameters:
 **************************************************************************/

